# My first package

This is my first package I contribute to Pypi. I build this package because I wanted an easy way to communicate with the
Teamleader API. The Python language is my way to go. Suggestions for improvements are always welcome.

## Installation

To download Teamleader, either fork this github repo or simply use Pypi via pip.

```sh
$ pip install teamleader
```

## Using it

```sh
$ from teamleader import Client
$ tl = Client()
```

## License

MIT
